==> ftml-1.6.3.crate: ftml-1.6.3/src/parsing/rule/impls/italics.rs <==
/*
 * parsing/rule/impls/italics.rs
 *
 * ftml - Library to parse Wikidot text
 * Copyright (C) 2019-2021 Wikijump Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

use super::prelude::*;

pub const RULE_ITALICS: Rule = Rule {
    name: "italics",
    position: LineRequirement::Any,
    try_consume_fn,
};

fn try_consume_fn<'p, 'r, 't>(
    log: &Logger,
    parser: &'p mut Parser<'r, 't>,
) -> ParseResult<'r, 't, Elements<'t>> {
    info!(log, "Trying to create italics (emphasis) container");

    check_step(parser, Token::Italics)?;

    collect_container(
        log,
        parser,
        RULE_ITALICS,
        ContainerType::Italics,
        &[ParseCondition::current(Token::Italics)],
        &[
            ParseCondition::current(Token::ParagraphBreak),
            ParseCondition::token_pair(Token::Italics, Token::Whitespace),
            ParseCondition::token_pair(Token::Whitespace, Token::Italics),
        ],
        None,
    )
}

==> ftml-1.16.0.crate: ftml-1.16.0/src/parsing/rule/impls/italics.rs <==
/*
 * parsing/rule/impls/italics.rs
 *
 * ftml - Library to parse Wikidot text
 * Copyright (C) 2019-2022 Wikijump Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

use super::prelude::*;

pub const RULE_ITALICS: Rule = Rule {
    name: "italics",
    position: LineRequirement::Any,
    try_consume_fn,
};

fn try_consume_fn<'p, 'r, 't>(
    parser: &'p mut Parser<'r, 't>,
) -> ParseResult<'r, 't, Elements<'t>> {
    info!("Trying to create italics (emphasis) container");
    check_step(parser, Token::Italics)?;
    collect_container(
        parser,
        RULE_ITALICS,
        ContainerType::Italics,
        &[ParseCondition::current(Token::Italics)],
        &[
            ParseCondition::current(Token::ParagraphBreak),
            ParseCondition::token_pair(Token::Italics, Token::Whitespace),
            ParseCondition::token_pair(Token::Whitespace, Token::Italics),
        ],
        None,
    )
}
